@@ -22,18 +22,25 @@
  * 02110-1301 USA
 */
 /*******************************************************************************/
+#ifndef _weather_common_h
+#define _weather_common_h 1
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <gtk/gtk.h>
 #include <hildon/hildon.h>
 #include <locale.h>
 #include <libhildondesktop/libhildondesktop.h>
+#include <libosso.h>
 
 #define GETTEXT_PACKAGE "livewp"
 #include <glib/gi18n-lib.h>
 
 #define THEME_PATH "/usr/share/livewp/theme"
-#define SHORT_TIMER 50 /* 100 milisecond */
+#define SHORT_TIMER 75 /* 100 milisecond */
 //#define LONG_TIMER 5*60*1000 /* 10 minutes */
-#define LONG_TIMER  10*1000 /* 10 minutes */
+#define LONG_TIMER  20*1000 /* 10 minutes */
 enum { SHORT_TIMER_TYPE, LONG_TIMER_TYPE };
 #define SKY_LEVEL 0 
 #define SUN_LEVEL 0 
@@ -55,6 +62,9 @@ struct _Animation_WallpaperPrivate
     GtkWidget *main_widget;
     GtkWidget *right_corner;
     AWallpaperPlugin *desktop_plugin;
+    DBusConnection      *dbus_conn;
+    DBusConnection      *dbus_conn_session;
+    osso_context_t      *osso;
 };
 
 struct _AWallpaperPlugin
@@ -85,5 +95,13 @@ typedef struct {
     time_t time_start_animation;
     gint duration_animation;
     void (*func_probability)(gpointer);
+    GPtrArray *child;
 
 } Actor;
+#define LIVEWP_SIGNAL_INTERFACE "org.maemo.livewp"
+#define LIVEWP_SIGNAL_PATH "/org/maemo/livewp"
+#define LIVEWP_SIGNAL_RELOAD_CONFIG_INTERFACE "org.maemo.livewp.reload_config"
+#define LIVEWP_SIGNAL_RELOAD_CONFIG_PATH "/org/maemo/livewp/reload_config"
+#define LIVEWP_RELOAD_CONFIG "reload_config"
+#define LIVEWP_RELOAD_PLUGIN "reload_plugin"
+#endif
