@@ -23,7 +23,9 @@
 */
 /*******************************************************************************/
 #include "livewp-common.h"
-void lw_settings(GtkWidget *widget, Animation_WallpaperPrivate *priv);
+void lw_settings(Animation_WallpaperPrivate *priv, gpointer data);
 void save_config(Animation_WallpaperPrivate *priv);
 void reload_scene(AWallpaperPlugin *desktop_plugin);
+GtkWidget* create_settings(void);
+void show_settings(GtkWidget *widget, Animation_WallpaperPrivate *priv);
 
